//
// Copyright(C) Sergey A. Galin, 2008. http://sageshome.net/
//
// This program is distributed under terms of GNU General Public License,
// version 2 or higher, published by Free Software Foundation, at your option.
// See COPYING.txt for more information.
//

//-----------------------------------------------------------------------------
// RIFF WAV file format definition and simple tools
//-----------------------------------------------------------------------------

#if !defined(VT_RIFF_H)
#define VT_RIFF_H

typedef unsigned int DWORD;
typedef unsigned short WORD;
typedef DWORD FOURCC;

#define MAKEFOURCC(a,b,c,d) \
	(DWORD((unsigned char)a)|(DWORD((unsigned char)b)<<8)| \
	DWORD((unsigned char)c)<<16|DWORD((unsigned char)d<<24))

// IMPORTANT:
// Default initialization done by Init() sets all fields as for CD Audio format:
// 16-bit signed PCM, stereo. This behaviour should not be changed.
struct TRIFFWavHeader
{
	// Some comments from http://www.ringthis.com/dev/wave_format.htm
	FOURCC riffheader;		// "RIFF"
	DWORD  WAVElen;			// Size of the file, DWORD
							// The file size LESS the size of the "RIFF" description (4 bytes) 
							// and the size of file description (4 bytes). This is usually file size - 8.
	FOURCC WAVEsig;         // "WAVE"
	FOURCC fmtsig;          // "fmt "
	DWORD  fmtlen;			// DWORD, The size of the WAVE type format (2 bytes) 
							// + mono/stereo flag (2 bytes) + sample rate (4 bytes) + 
							// bytes/sec (4 bytes) + block alignment (2 bytes) + bits/sample (2 bytes). 
							// This is usually 16 (or 0x10).
	WORD   FormatTag;		// 1 == PCM
	WORD   Channels;		// Mono == 1, Stereo == 2
	DWORD  SamplesPerSec;	// Sample rate, DWORD
	DWORD  AvgBytesPerSec;	// bps, DWORD
	WORD   BlockAlign;		// Block alignment
	WORD   BitsPerSample;	/* format specific for PCM */
	FOURCC dataheader;		// "data"
	DWORD  datalen;			// number of bytes in data

	void Init();  // Sets all fields by default	
	bool VerifySignatures(); // Checks that all text signatures are OK
	bool IsValidPCMWav(); // Checks that the header is valid for simple PCM Wav
	const TRIFFWavHeader* GetDefaultHeader();
};


#endif


